@@ -10,11 +10,11 @@ from github import Github
 import yaml 
 ENDPOINT = "webhook"
 
-a_yaml_file = open("./configdemo.yaml")
-parsed_yaml_file = yaml.load(a_yaml_file, Loader=yaml.FullLoader)
+# a_yaml_file = open("./configdemo.yaml")
+# parsed_yaml_file = yaml.load(a_yaml_file, Loader=yaml.FullLoader)
 
-username=parsed_yaml_file["user_name"]
-token=parsed_yaml_file["access_token"]
+# username=parsed_yaml_file["user_name"]
+# token=parsed_yaml_file["access_token"]
 @view_defaults(
     route_name=ENDPOINT, renderer="json", request_method="POST"
 )
@@ -50,8 +50,8 @@ class PayloadView():
 # create webhook on a particular repo
 @click.command()
 @click.option('--path', '-e', default="config file ", prompt='Enter the path ', help='Enter the username of ')
-@click.option('--host', '-e', default="host file ", prompt='Enter the host  ', help='enter the host ')
-def create_webhook(path,host):
+@click.option('--serverurl', '-e', default="host file ", prompt='Enter the host  ', help='enter the host ')
+def create_webhook(path,serverurl):
 
     os.chdir(path)
     a_yaml_file = open("./config.yaml")
@@ -59,11 +59,12 @@ def create_webhook(path,host):
 
     username=parsed_yaml_file["user_name"]
     token=parsed_yaml_file["access_token"]
+    repo=parsed_yaml_file["repository"]
     access_token = token# "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"
     OWNER = username#"AkashAi7" # github account name
-    REPO_NAME = "demosession1"# github repository name
+    REPO_NAME = repo#"demosession1"# github repository name
     EVENTS = ["*"]      # Events on github
-    HOST = host#"343328894880.ngrok.io"  # ngrok tunnel
+    HOST = serverurl#"343328894880.ngrok.io"  # ngrok tunnel
     config = {
         "url": "http://{host}/{endpoint}".format(host=HOST, endpoint=ENDPOINT),
         "content_type": "json"
